@@ -5,6 +5,7 @@ import logging
 import os
 import re
 import urllib.parse
+from enum import EnumMeta
 
 from pydantic import BaseModel, Extra
 from pydantic.fields import ModelField
@@ -34,6 +35,16 @@ class AindModel(BaseModel, extra=Extra.forbid):
     """BaseModel that disallows extra fields"""
 
 
+class BaseNameEnumMeta(EnumMeta):
+    """Allows to create complicated enum based on attribute name."""
+
+    def __call__(cls, value, *args, **kw):
+        """Allow enum to be set by a string."""
+        if isinstance(value, str):
+            value = getattr(cls, value.upper())
+        return super().__call__(value, *args, **kw)
+
+
 class BaseName(AindModel):
     """A simple model associating a name with an abbreviation"""
 
