@@ -74,13 +74,9 @@ class Registration(DataProcess):
     """Description of tile alignment coordinate transformations"""
 
     registration_type: RegistrationType = Field(
-        ..., 
-        title="Registration type",
-        description="Either inter channel across different channels or intra channel"
-        )
+        ..., title="Registration type", description="Either inter channel across different channels or intra channel"
+    )
     registration_channel: Optional[int] = Field(
-        None, 
-        title="Registration channel",
-        description="Channel registered to when inter channel"
-        )
+        None, title="Registration channel", description="Channel registered to when inter channel"
+    )
     tiles: List[Tile] = Field(..., title="Data tiles")
